pilas.actores.nave.Nave

Package pilas :: Package actores :: Module nave :: Class Nave |
[hide private]
[frames] | no frames]

# Class Nave

source code

                   object --+
                            |
    estudiante.Estudiante --+
                            |
                  actor.Actor --+
                                |
                  animado.Animado --+
                                    |
                  animacion.Animacion --+
                                        |
                                       Nave

Representa una nave que puede disparar.

.. image:: images/actores/nave.png

Instance Methods | [hide private]
__init__(self, x=0, y=0, velocidad=2) Constructor de la Nave. | source code
actualizar(self) Hace avanzar la animacion. | source code
definir_enemigos(self, grupo, cuando_elimina_enemigo=None) Hace que una nave tenga como enemigos a todos los actores del grupo. | source code
hacer_explotar_al_enemigo(self, mi_disparo, el_enemigo) Es el método que se invoca cuando se produce una colisión 'tiro <-> enemigo' | source code
Inherited from `animacion.Animacion`: `definir_velocidad_de_animacion`, `obtener_velocidad_de_animacion` Inherited from `animado.Animado`: `definir_cuadro` Inherited from `actor.Actor`: `__cmp__`, `__mul__`, `__str__`, `actor_mas_cercano`, `anexar`, `colisiona_con`, `colisiona_con_un_punto`, `decir`, `definir_centro`, `definir_color`, `definir_escala`, `definir_imagen`, `definir_posicion`, `definir_rotacion`, `definir_transparencia`, `destruir`, `dibujar`, `distancia_al_punto`, `distancia_con`, `duplicar`, `eliminar`, `es_fondo`, `esta_fuera_de_la_pantalla`, `get_abajo`, `get_arriba`, `get_derecha`, `get_espejado`, `get_fijo`, `get_imagen`, `get_izquierda`, `get_rotation`, `get_scale`, `get_scale_x`, `get_scale_y`, `get_transparencia`, `get_vx`, `get_vy`, `get_x`, `get_y`, `get_z`, `imitar`, `obtener_alto`, `obtener_ancho`, `obtener_centro`, `obtener_escala`, `obtener_imagen`, `obtener_posicion`, `obtener_rotacion`, `pre_actualizar`, `set_abajo`, `set_arriba`, `set_derecha`, `set_espejado`, `set_fijo`, `set_imagen`, `set_izquierda`, `set_rotation`, `set_scale`, `set_scale_x`, `set_scale_y`, `set_transparencia`, `set_x`, `set_y`, `set_z` Inherited from `actor.Actor` (private): `_eliminar_anexados`, `_interpretar_y_convertir_posicion` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__` Inherited from `estudiante.Estudiante`: `actualizar_comportamientos`, `actualizar_habilidades`, `agregar_habilidad`, `aprender`, `eliminar_comportamientos`, `eliminar_habilidad`, `eliminar_habilidades`, `hacer`, `hacer_luego`, `obtener_habilidad`, `tiene_comportamiento`, `tiene_habilidad` Inherited from `estudiante.Estudiante` (private): `_adoptar_el_siguiente_comportamiento`

Properties | [hide private]
Inherited from `animacion.Animacion`: `velocidad_de_animacion` Inherited from `actor.Actor`: `abajo`, `alto`, `ancho`, `arriba`, `centro`, `derecha`, `escala`, `escala_x`, `escala_y`, `espejado`, `fijo`, `imagen`, `izquierda`, `rotacion`, `transparencia`, `vx`, `vy`, `x`, `y`, `z` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, x=0, y=0, velocidad=2) (Constructor) | source code
Constructor de la Nave. :param x: posicion horizontal de la nave. :type x: int :param y: posicion vertical de la nave. :type y: int :param velocidad: Velocidad que llevará la nave. :type velocidad: int Overrides: estudiante.Estudiante.__init__

### actualizar(self) | source code
Hace avanzar la animacion. Overrides: actor.Actor.actualizar (inherited documentation)

### definir_enemigos(self, grupo, cuando_elimina_enemigo=None) | source code
Hace que una nave tenga como enemigos a todos los actores del grupo. :param grupo: El grupo de actores que serán sus enemigos. :type grupo: array :param cuando_elimina_enemigo: Funcion que se ejecutará cuando se elimine un enemigo.

### hacer_explotar_al_enemigo(self, mi_disparo, el_enemigo) | source code
Es el método que se invoca cuando se produce una colisión 'tiro <-> enemigo' :param mi_disparo: El disparo de la nave. :param el_enemigo: El enemigo que se eliminará.